aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ObjectType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ObjectType.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ObjectType.java72
1 files changed, 36 insertions, 36 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ObjectType.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ObjectType.java
index 10db581..9ddfc1e 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ObjectType.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ObjectType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,37 +10,37 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlID;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
-import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
-import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlID;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
+import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.w3c.dom.Element;
/**
- * <p>Java class for ObjectType complex type.
+ * <p>Java-Klasse für ObjectType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="ObjectType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence maxOccurs="unbounded" minOccurs="0">
- * &lt;any processContents='lax'/>
- * &lt;/sequence>
- * &lt;attribute name="Id" type="{http://www.w3.org/2001/XMLSchema}ID" />
- * &lt;attribute name="MimeType" type="{http://www.w3.org/2001/XMLSchema}string" />
- * &lt;attribute name="Encoding" type="{http://www.w3.org/2001/XMLSchema}anyURI" />
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="ObjectType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence maxOccurs="unbounded" minOccurs="0"&gt;
+ * &lt;any processContents='lax'/&gt;
+ * &lt;/sequence&gt;
+ * &lt;attribute name="Id" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
+ * &lt;attribute name="MimeType" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ * &lt;attribute name="Encoding" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -71,7 +71,7 @@ public class ObjectType {
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the content property.
*
* <p>
@@ -83,8 +83,8 @@ public class ObjectType {
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link String }
* {@link Object }
+ * {@link String }
* {@link Element }
*
*
@@ -97,7 +97,7 @@ public class ObjectType {
}
/**
- * Gets the value of the id property.
+ * Ruft den Wert der id-Eigenschaft ab.
*
* @return
* possible object is
@@ -109,7 +109,7 @@ public class ObjectType {
}
/**
- * Sets the value of the id property.
+ * Legt den Wert der id-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -121,7 +121,7 @@ public class ObjectType {
}
/**
- * Gets the value of the mimeType property.
+ * Ruft den Wert der mimeType-Eigenschaft ab.
*
* @return
* possible object is
@@ -133,7 +133,7 @@ public class ObjectType {
}
/**
- * Sets the value of the mimeType property.
+ * Legt den Wert der mimeType-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -145,7 +145,7 @@ public class ObjectType {
}
/**
- * Gets the value of the encoding property.
+ * Ruft den Wert der encoding-Eigenschaft ab.
*
* @return
* possible object is
@@ -157,7 +157,7 @@ public class ObjectType {
}
/**
- * Sets the value of the encoding property.
+ * Legt den Wert der encoding-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -71,7 +71,7 @@ public class ObjectType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the content property.
*